==> enterprisemodules-ora_config-3.20.0.tar.gz: enterprisemodules-ora_config-3.20.0/lib/puppet/type/shared/ora_config/common_grants.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:common_grants, :array_matching => :all) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access
  include Puppet_X::EnterpriseModules::Oracle::GrantProperty
  include Puppet_X::EnterpriseModules::Oracle::CreateOnly
  include Puppet_X::EnterpriseModules::Oracle::Mungers::Upcase

  data_type('Optional[Array[String[1]]]')

  desc <<-DESC
    Common grants for this user or role.

    This property is only functional when applied on container databases.

    All the common grants this resource has. Here is an example on how to use this on an `ora_user`:

      ora_user { 'my_user@sid':
        ...
        common_grants => ['UNLIMITED TABLESPACE', 'CREATE PUBLIC SYNONYM'].
        ...
      }

    Here is an example on how to use this on an `ora_role`:

      ora_ora_role { 'my_role@sid':
        ...
        common_grants => ['UNLIMITED TABLESPACE', 'CREATE PUBLIC SYNONYM'].
        ...
      }

  DESC

  #
  # This property manages grants without admin options
  #
  def self.admin
    false
  end

  def self.common
    true
  end

  validate do |value|
    fail "#{value} is an invalid right. Use ora_object_permissions to set permissions on objects" if value.include?('.')
    fail "#{value} is an invalid right. Use ora_object_permissions to set permissions on objects" if value.include?(' on ')

    true
  end

  #
  # because the order may differ, but they are still the same,
  # to decide if they are equal, first do a sort on is and should
  #
  def insync?(is)
    is = [] if is.to_s == 'absent' || is.nil?
    is.sort == assembled_value.sort
  end

  def revoked_rights
    current_rights - value
  end

  #
  # Assemble the actua value based on all grant and revoked properties
  #
  def assembled_value
    granted = resource[:common_granted].nil? ? [] : resource[:common_granted]
    revoked = resource[:common_revoked].nil? ? [] : resource[:common_revoked]
    (value + granted - revoked).uniq
  end

  def granted_rights
    assembled_value - current_rights
  end
end

==> enterprisemodules-ora_config-3.25.0.tar.gz: enterprisemodules-ora_config-3.25.0/lib/puppet/type/shared/ora_config/common_grants.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:common_grants, :array_matching => :all) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Access
  include PuppetX::EnterpriseModules::Oracle::GrantProperty
  include PuppetX::EnterpriseModules::Oracle::CreateOnly
  include PuppetX::EnterpriseModules::Oracle::Mungers::Upcase

  data_type('Optional[Array[String[1]]]')

  desc <<-DESC
    Common grants for this user or role.

    This property is only functional when applied on container databases.

    All the common grants this resource has. Here is an example on how to use this on an `ora_user`:

      ora_user { 'my_user@sid':
        ...
        common_grants => ['UNLIMITED TABLESPACE', 'CREATE PUBLIC SYNONYM'].
        ...
      }

    Here is an example on how to use this on an `ora_role`:

      ora_ora_role { 'my_role@sid':
        ...
        common_grants => ['UNLIMITED TABLESPACE', 'CREATE PUBLIC SYNONYM'].
        ...
      }

  DESC

  #
  # This property manages grants without admin options
  #
  def self.admin
    false
  end

  def self.common
    true
  end

  validate do |value|
    fail "#{value} is an invalid right. Use ora_object_permissions to set permissions on objects" if value.include?('.')
    fail "#{value} is an invalid right. Use ora_object_permissions to set permissions on objects" if value.include?(' on ')

    true
  end

  #
  # because the order may differ, but they are still the same,
  # to decide if they are equal, first do a sort on is and should
  #
  def insync?(is)
    is = [] if is.to_s == 'absent' || is.nil?
    is.sort == assembled_value.sort
  end

  def revoked_rights
    current_rights - value
  end

  #
  # Assemble the actua value based on all grant and revoked properties
  #
  def assembled_value
    granted = resource[:common_granted].nil? ? [] : resource[:common_granted]
    revoked = resource[:common_revoked].nil? ? [] : resource[:common_revoked]
    (value + granted - revoked).uniq
  end

  def granted_rights
    assembled_value - current_rights
  end
end
